<?php

class ContactsController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to 'column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='column2';

	/**
	 * @var CActiveRecord the currently loaded data model instance.
	 */
	private $_model;

	/**
	 * Displays a particular model.
	 */
	public function actionView()
	{
		$model = $this->loadModel();
		if (!Yii::app()->user->checkAccess('readContact', array('contact'=>$model))) {
			throw new CHttpException(403, 'Forbidden');
		}
		
		$this->render('view',array(
			'model'=>$model,
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		if (!Yii::app()->user->checkAccess('createContact')) {
			throw new CHttpException(403, 'Forbidden');
		}
		
		$model=new Contacts;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Contacts']))
		{
			$model->attributes=$_POST['Contacts'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->c_id));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionUpdate()
	{
		$model=$this->loadModel();
		
		if (!Yii::app()->user->checkAccess('updateContact', array('contact'=>$model))) {
			throw new CHttpException(403, 'Forbidden');
		}
		
		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Contacts']))
		{
			$model->attributes=$_POST['Contacts'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->c_id));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'index' page.
	 */
	public function actionDelete()
	{
		$model = $this->loadModel();
		
		if (!Yii::app()->user->checkAccess('deleteContact', array('contact'=>$model))) {
			throw new CHttpException(403, 'Forbidden');
		}
		
		if(Yii::app()->request->isPostRequest)
		{
			// we only allow deletion via POST request
			$model->delete();

			// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
			if(!isset($_GET['ajax']))
				$this->redirect(array('index'));
		}
		else {
			throw new CHttpException(400,'Invalid request. Please do not repeat this request again.');
		}
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		if (!Yii::app()->user->checkAccess('viewContacts')) {
			throw new CHttpException(403, 'Forbidden');
		}
		
		$dataProvider=new CActiveDataProvider('Contacts', array(
			'criteria'=>array(
				'condition'=>'c_user_id=:user_id',
				'params'=>array(':user_id'=>Yii::app()->user->id),
			),
		));
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		if (!Yii::app()->user->checkAccess('viewContacts')) {
			throw new CHttpException(403, 'Forbidden');
		}
		
//		$criteria = new CDbCriteria;
//		$criteria->condition = 'c_user_id=:user_id';
//		$criteria->params = array(':user_id'=>Yii::app()->user->id);
		
		$model=new Contacts('search');
//		var_dump($model);
		//$model->setDbCriteria($criteria);
		if(isset($_GET['Contacts']))
			$model->attributes=$_GET['Contacts'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 */
	public function loadModel()
	{
		if($this->_model===null)
		{
			if(isset($_GET['id']))
				$this->_model=Contacts::model()->findbyPk($_GET['id'],
					'c_user_id=:user_id', array(':user_id'=>Yii::app()->user->id));
			if($this->_model===null)
				throw new CHttpException(404,'The requested page does not exist.');
		}
		return $this->_model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param CModel the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='contacts-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}
